@@ -2,7 +2,7 @@
 {-# LANGUAGE PatternSynonyms #-}
 {-|
 Module      : Lua
-Copyright   : © 2021-2023 Albert Krewinkel
+Copyright   : © 2021-2025 Albert Krewinkel
 License     : MIT
 Maintainer  : Albert Krewinkel <tarleb@hslua.org>
 Stability   : beta
@@ -261,6 +261,9 @@ module Lua
     -- * Push Haskell functions
   , hslua_pushhsfunction
 
+    -- * Predefined values in the registry
+  , pattern LUA_RIDX_GLOBALS
+
     -- * Version and copyright info
   , pattern LUA_VERSION
   , pattern LUA_RELEASE
